==> gis-viewer-3.0.1-20130523.162045-23.jar: org/gcube/portlets/user/gisviewer/client/resources/Images.java <==
package org.gcube.portlets.user.gisviewer.client.resources;

import org.gcube.portlets.user.gisviewer.client.GisViewer;

import com.google.gwt.user.client.ui.AbstractImagePrototype;

public class Images {

	public static AbstractImagePrototype iconAtompub() {
		return AbstractImagePrototype.create(GisViewer.resources.iconAtompub());
	}

	public static AbstractImagePrototype iconGeorss() {
		return AbstractImagePrototype.create(GisViewer.resources.iconGeorss());
	}

	public static AbstractImagePrototype iconGif() {
		return AbstractImagePrototype.create(GisViewer.resources.iconGif());
	}

	public static AbstractImagePrototype iconJpeg() {
		return AbstractImagePrototype.create(GisViewer.resources.iconJpeg());
	}

	public static AbstractImagePrototype iconKml() {
		return AbstractImagePrototype.create(GisViewer.resources.iconKml());
	}

	public static AbstractImagePrototype iconPdf() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPdf());
	}

	public static AbstractImagePrototype iconPng() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPng());
	}

	public static AbstractImagePrototype iconSvg() {
		return AbstractImagePrototype.create(GisViewer.resources.iconSvg());
	}

	public static AbstractImagePrototype iconTiff() {
		return AbstractImagePrototype.create(GisViewer.resources.iconTiff());
	}

	public static AbstractImagePrototype iconExport() {
		return AbstractImagePrototype.create(GisViewer.resources.iconExport());
	}

	public static AbstractImagePrototype iconFilter() {
		return AbstractImagePrototype.create(GisViewer.resources.iconFilter());
	}

	public static AbstractImagePrototype iconTable() {
		return AbstractImagePrototype.create(GisViewer.resources.iconTable());
	}

	public static AbstractImagePrototype iconRefresh() {
		return AbstractImagePrototype.create(GisViewer.resources.iconRefresh());
	}

	public static AbstractImagePrototype iconTransect() {
		return AbstractImagePrototype.create(GisViewer.resources.iconTransect());
	}

	public static AbstractImagePrototype iconLegend() {
		return AbstractImagePrototype.create(GisViewer.resources.iconLegend());
	}

	public static AbstractImagePrototype iconSave() {
		return AbstractImagePrototype.create(GisViewer.resources.iconSave());
	}

	public static AbstractImagePrototype iconExecuteQuery() {
		return AbstractImagePrototype.create(GisViewer.resources.iconArrowBlueRight());
	}

	public static AbstractImagePrototype iconRemoveCqlFilter() {
		return AbstractImagePrototype.create(GisViewer.resources.iconRemoveCqlFilter());
	}

	public static AbstractImagePrototype iconToolbarRemove() {
		return AbstractImagePrototype.create(GisViewer.resources.iconToolbarRemove());
	}

	
	public static AbstractImagePrototype iconMaxExtent() {
		return AbstractImagePrototype.create(GisViewer.resources.iconMaxExtent());
	}

	public static AbstractImagePrototype iconZoomIn() {
		return AbstractImagePrototype.create(GisViewer.resources.iconZoomIn());
	}

	public static AbstractImagePrototype iconZoomOut() {
		return AbstractImagePrototype.create(GisViewer.resources.iconZoomOut());
	}

	public static AbstractImagePrototype iconPan() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPan());
	}

	public static AbstractImagePrototype iconClickData() {
		return AbstractImagePrototype.create(GisViewer.resources.iconClickData());
	}

	public static AbstractImagePrototype iconBoxData() {
		return AbstractImagePrototype.create(GisViewer.resources.iconBoxData());
	}
}

==> gis-viewer-3.6.2-20150323.163646-16.jar: org/gcube/portlets/user/gisviewer/client/resources/Images.java <==
package org.gcube.portlets.user.gisviewer.client.resources;

import org.gcube.portlets.user.gisviewer.client.GisViewer;

import com.google.gwt.user.client.ui.AbstractImagePrototype;

public class Images {

	public static AbstractImagePrototype iconAtompub() {
		return AbstractImagePrototype.create(GisViewer.resources.iconAtompub());
	}

	public static AbstractImagePrototype iconGeorss() {
		return AbstractImagePrototype.create(GisViewer.resources.iconGeorss());
	}

	public static AbstractImagePrototype iconGif() {
		return AbstractImagePrototype.create(GisViewer.resources.iconGif());
	}

	public static AbstractImagePrototype iconJpeg() {
		return AbstractImagePrototype.create(GisViewer.resources.iconJpeg());
	}

	public static AbstractImagePrototype iconKml() {
		return AbstractImagePrototype.create(GisViewer.resources.iconKml());
	}

	public static AbstractImagePrototype iconPdf() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPdf());
	}

	public static AbstractImagePrototype iconPng() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPng());
	}

	public static AbstractImagePrototype iconSvg() {
		return AbstractImagePrototype.create(GisViewer.resources.iconSvg());
	}

	public static AbstractImagePrototype iconTiff() {
		return AbstractImagePrototype.create(GisViewer.resources.iconTiff());
	}

	public static AbstractImagePrototype iconExport() {
		return AbstractImagePrototype.create(GisViewer.resources.iconExport());
	}

	public static AbstractImagePrototype iconFilter() {
		return AbstractImagePrototype.create(GisViewer.resources.iconFilter());
	}

	public static AbstractImagePrototype iconTable() {
		return AbstractImagePrototype.create(GisViewer.resources.iconTable());
	}

	public static AbstractImagePrototype iconRefresh() {
		return AbstractImagePrototype.create(GisViewer.resources.iconRefresh());
	}

	public static AbstractImagePrototype iconTransect() {
		return AbstractImagePrototype.create(GisViewer.resources.iconTransect());
	}

	public static AbstractImagePrototype iconLegend() {
		return AbstractImagePrototype.create(GisViewer.resources.iconLegend());
	}

	public static AbstractImagePrototype iconSave() {
		return AbstractImagePrototype.create(GisViewer.resources.iconSave());
	}

	public static AbstractImagePrototype iconExecuteQuery() {
		return AbstractImagePrototype.create(GisViewer.resources.iconArrowBlueRight());
	}

	public static AbstractImagePrototype iconRemoveCqlFilter() {
		return AbstractImagePrototype.create(GisViewer.resources.iconRemoveCqlFilter());
	}

	public static AbstractImagePrototype iconToolbarRemove() {
		return AbstractImagePrototype.create(GisViewer.resources.iconToolbarRemove());
	}

	public static AbstractImagePrototype iconToolbarRemove24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconToolbarRemove24());
	}
	
	public static AbstractImagePrototype iconMaxExtent() {
		return AbstractImagePrototype.create(GisViewer.resources.iconMaxExtent());
	}

	public static AbstractImagePrototype iconZoomIn() {
		return AbstractImagePrototype.create(GisViewer.resources.iconZoomIn());
	}

	public static AbstractImagePrototype iconZoomOut() {
		return AbstractImagePrototype.create(GisViewer.resources.iconZoomOut());
	}
	
	public static AbstractImagePrototype iconZoomIn24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconZoomIn24());
	}

	public static AbstractImagePrototype iconZoomOut24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconZoomOut24());
	}

	public static AbstractImagePrototype iconPan() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPan());
	}

	public static AbstractImagePrototype iconClickData() {
		return AbstractImagePrototype.create(GisViewer.resources.iconClickData());
	}

	public static AbstractImagePrototype iconBoxData() {
		return AbstractImagePrototype.create(GisViewer.resources.iconBoxData());
	}
	
	public static AbstractImagePrototype gisViewerIcon() {
		return AbstractImagePrototype.create(GisViewer.resources.gisViewerIcon());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype iconMaxExtent24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconMaxExtent24());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype iconPan24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconPan24());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype iconClickData24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconClickData24());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype iconBoxData24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconBoxData24());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype iconExport24() {
		return AbstractImagePrototype.create(GisViewer.resources.iconExport24());
	}
}
